| AcqOptimizerDirect | R Documentation |
Direct acquisition function optimizer.
Calls nloptr() from nloptr with the NLOPT_GN_DIRECT_L algorithm.
In its default setting, the algorithm runs for at most 100 * D^2 function evaluations,
where D is the dimension of the search space.
The optimization stops when the relative tolerance of the parameters is less than 10^-4.
Only fully numeric search spaces (all parameters of type p_dbl) are supported.
skip_already_evaluatedlogical(1)
Should the proposed candidate be rejected if it was already evaluated on the actual bbotk::OptimInstance?
If TRUE and the candidate was already evaluated, an error is raised so that the loop_function can
propose a randomly sampled point instead.
Default is TRUE.
The following termination parameters can be used.
stopvalnumeric(1)
Stop value.
Deactivate with -Inf (Default).
maxevalinteger(1)
Maximum number of evaluations.
Default is 100 * D^2, where D is the dimension of the search space.
Deactivate with -1L.
xtol_relnumeric(1)
Relative tolerance of the parameters.
Default is 10^-4.
Deactivate with -1.
xtol_absnumeric(1)
Absolute tolerance of the parameters.
Deactivate with -1 (Default).
ftol_relnumeric(1)
Relative tolerance of the objective function.
Deactivate with -1 (Default).
ftol_absnumeric(1)
Absolute tolerance of the objective function.
Deactivate with -1 (Default).
AcqOptimizer -> AcqOptimizerDirect
state(nloptr::nloptr() result)
Result of the last optimization run.
print_id(character)
Id used when printing.
label(character(1))
Label for this object.
Can be used in tables, plot and text output instead of the ID.
man(character(1))
String in the format [pkg]::[topic] pointing to a manual page for this object.
AcqOptimizerDirect$new()Creates a new instance of this R6 class.
AcqOptimizerDirect$new(acq_function = NULL)
acq_function(NULL | AcqFunction).
AcqOptimizerDirect$optimize()Optimize the acquisition function.
AcqOptimizerDirect$optimize()
data.table::data.table() with 1 row per candidate.
AcqOptimizerDirect$reset()Reset the acquisition function optimizer.
Clears the state of the previous optimization run.
AcqOptimizerDirect$reset()
AcqOptimizerDirect$clone()The objects of this class are cloneable with this method.
AcqOptimizerDirect$clone(deep = FALSE)
deepWhether to make a deep clone.
NLOPT_GN_DIRECT_L is a deterministic global optimizer that ignores the starting point.
Restarts would only repeat the identical search, so the optimizer does not support them.
if (requireNamespace("nloptr")) {
acqo("direct")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.