AcqOptimizerLocalSearch: Local Search Acquisition Function Optimizer

AcqOptimizerLocalSearchR Documentation

Local Search Acquisition Function Optimizer

Description

Local search acquisition function optimizer. Calls bbotk::local_search(). For the meaning of the control parameters, see bbotk::local_search_control(). The termination stops when the budget defined by the n_searches, n_steps, and n_neighs parameters is exhausted.

If skip_already_evaluated is TRUE (default) and the proposed candidate was already evaluated on the actual bbotk::OptimInstance, an error is raised so that the loop_function can propose a randomly sampled point instead.

Super class

AcqOptimizer -> AcqOptimizerLocalSearch

Public fields

state

(list())
Result of the last bbotk::local_search() call.

Active bindings

print_id

(character)
Id used when printing.

label

(character(1))
Label for this object. Can be used in tables, plot and text output instead of the ID.

man

(character(1))
String in the format ⁠[pkg]::[topic]⁠ pointing to a manual page for this object.

Methods

Public methods

Inherited methods

AcqOptimizerLocalSearch$new()

Creates a new instance of this R6 class.

Usage
AcqOptimizerLocalSearch$new(acq_function = NULL)
Arguments
acq_function

(NULL | AcqFunction).


AcqOptimizerLocalSearch$optimize()

Optimize the acquisition function.

Usage
AcqOptimizerLocalSearch$optimize()
Returns

data.table::data.table() with 1 row per candidate.


AcqOptimizerLocalSearch$reset()

Reset the acquisition function optimizer.

Clears the state of the previous optimization run.

Usage
AcqOptimizerLocalSearch$reset()

AcqOptimizerLocalSearch$clone()

The objects of this class are cloneable with this method.

Usage
AcqOptimizerLocalSearch$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

Examples

acqo("local_search")

mlr3mbo documentation built on July 21, 2026, 5:08 p.m.