AcqOptimizerRandomSearch: Random Search Acquisition Function Optimizer

AcqOptimizerRandomSearchR Documentation

Random Search Acquisition Function Optimizer

Description

Random search acquisition function optimizer. By default, it samples 100 * D^2 random points in the search space, where D is the dimension of the search space. The point with the highest acquisition value is returned.

Parameters

n_evals

integer(1)
Number of random points to sample. Default is 100 * D^2, where D is the dimension of the search space.

skip_already_evaluated

logical(1)
Should the proposed candidate be rejected if it was already evaluated on the actual bbotk::OptimInstance? If TRUE and the candidate was already evaluated, an error is raised so that the loop_function can propose a randomly sampled point instead. Default is TRUE.

Super class

AcqOptimizer -> AcqOptimizerRandomSearch

Active bindings

print_id

(character)
Id used when printing.

label

(character(1))
Label for this object. Can be used in tables, plot and text output instead of the ID.

man

(character(1))
String in the format ⁠[pkg]::[topic]⁠ pointing to a manual page for this object.

Methods

Public methods

Inherited methods

AcqOptimizerRandomSearch$new()

Creates a new instance of this R6 class.

Usage
AcqOptimizerRandomSearch$new(acq_function = NULL)
Arguments
acq_function

(NULL | AcqFunction).


AcqOptimizerRandomSearch$optimize()

Optimize the acquisition function.

Usage
AcqOptimizerRandomSearch$optimize()
Returns

data.table::data.table() with 1 row per candidate.


AcqOptimizerRandomSearch$clone()

The objects of this class are cloneable with this method.

Usage
AcqOptimizerRandomSearch$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

Examples

acqo("random_search")

mlr3mbo documentation built on July 21, 2026, 5:08 p.m.