(bbotk::OptimizerBatch | character(1))
bbotk::OptimizerBatch that is to be used or the name of the optimizer in mlr_acqoptimizers.
If optimizer is missing, the mlr_acqoptimizers dictionary is returned.
terminator
(bbotk::Terminator)
bbotk::Terminator that is to be used.
acq_function
(NULL | AcqFunction)
AcqFunction that is to be used.
Can also be NULL.
callbacks
(NULL | list of mlr3misc::Callback)
Callbacks used during acquisition function optimization.
...
(named list())
Named arguments passed to the constructor, to be set as parameters in the paradox::ParamSet.