| default_gp | R Documentation |
This is a helper function that constructs a default Gaussian Process mlr3learners::LearnerRegrKM
which is for example used in default_surrogate().
Constructs a Kriging learner "regr.km" with kernel "matern5_2".
If noisy = FALSE (default) a small nugget effect is added nugget.stability = 10^-8
to increase numerical stability to hopefully prevent crashes of DiceKriging.
If noisy = TRUE the nugget effect will be estimated with nugget.estim = TRUE.
If noisy = TRUE jitter is set to TRUE to circumvent a problem with DiceKriging
where already trained input values produce the exact trained output.
In general, instead of the default "BFGS" optimization method we use rgenoud ("gen"),
which is a hybrid algorithm,
to combine global search based on genetic algorithms and local search based on gradients.
This may improve the model fit and will less frequently produce a constant model prediction.
default_gp(noisy = FALSE)
noisy |
( |
mlr3learners::LearnerRegrKM
Other mbo_defaults:
default_acqfunction(),
default_acqoptimizer(),
default_loop_function(),
default_result_assigner(),
default_rf(),
default_surrogate(),
mbo_defaults
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.