Learn R Programming

mlr3mbo (version 1.2.1)

default_rf: Default Random Forest

Description

This is a helper function that constructs a default random forest mlr3learners::LearnerRegrRanger which is for example used in default_surrogate().

Usage

default_rf(noisy = FALSE)

Value

mlr3learners::LearnerRegrRanger

Arguments

noisy

(logical(1))
Whether the learner will be used in a noisy objective function scenario. See default_surrogate(). Currently, the constructed random forest is identical in the noisy and deterministic case, and the argument only exists for consistency with default_gp().

See Also

Other mbo_defaults: default_acqfunction(), default_acqoptimizer(), default_gp(), default_loop_function(), default_result_assigner(), default_surrogate(), mbo_defaults