| mlr_acqoptimizers | R Documentation |
A simple mlr3misc::Dictionary storing objects of class AcqOptimizer.
Each input transformation has an associated help page, see mlr_acqoptimizers[id].
For a more convenient way to retrieve and construct an acquisition function optimizer, see acqo().
R6::R6Class object inheriting from mlr3misc::Dictionary.
See mlr3misc::Dictionary.
Sugar function: acqo()
Other Dictionary:
mlr_acqfunctions,
mlr_input_trafos,
mlr_loop_functions,
mlr_output_trafos,
mlr_result_assigners
library(data.table)
as.data.table(mlr_acqoptimizers)
acqo("local_search")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.