Direct acquisition function optimizer.
Calls nloptr() from nloptr.
In its default setting, the algorithm restarts 5 * D times and runs at most for 100 * D^2 function evaluations, where D is the dimension of the search space.
Each run stops when the relative tolerance of the parameters is less than 10^-4.
The first iteration starts with the best point in the archive and the next iterations start from a random point.
restart_strategycharacter(1)
Restart strategy.
Can be "none" or "random".
Default is "none".
max_restartsinteger(1)
Maximum number of restarts.
Default is 5 * D (Default).
The following termination parameters can be used.
stopvalnumeric(1)
Stop value.
Deactivate with -Inf (Default).
maxevalinteger(1)
Maximum number of evaluations.
Default is 100 * D^2, where D is the dimension of the search space.
Deactivate with -1L.
xtol_relnumeric(1)
Relative tolerance of the parameters.
Default is 10^-4.
Deactivate with -1.
xtol_absnumeric(1)
Absolute tolerance of the parameters.
Deactivate with -1 (Default).
ftol_relnumeric(1)
Relative tolerance of the objective function.
Deactivate with -1. (Default).
ftol_absnumeric(1)
Absolute tolerance of the objective function.
Deactivate with -1 (Default).
mlr3mbo::AcqOptimizer -> AcqOptimizerDirect
state(list())
List of nloptr::nloptr() results.
print_id(character)
Id used when printing.
new()Creates a new instance of this R6 class.
AcqOptimizerDirect$new(acq_function = NULL)acq_function(NULL | AcqFunction).
data.table::data.table() with 1 row per candidate.
clone()The objects of this class are cloneable with this method.
AcqOptimizerDirect$clone(deep = FALSE)deepWhether to make a deep clone.
if (requireNamespace("nloptr")) {
acqo("direct")
}
Run the code above in your browser using DataLab