AcqOptimizerLocalSearch: Local Search Acquisition Function Optimizer

AcqOptimizerLocalSearchR Documentation

Local Search Acquisition Function Optimizer

Description

Local search acquisition function optimizer. Calls bbotk::local_search(). For the meaning of the control parameters, see bbotk::local_search_control(). The termination stops when the budget defined by the n_searches, n_steps, and n_neighs parameters is exhausted.

Super class

mlr3mbo::AcqOptimizer -> AcqOptimizerLocalSearch

Public fields

state

(list())
List of cmaes::cma_es() results.

Active bindings

print_id

(character)
Id used when printing.

Methods

Public methods

Inherited methods

Method new()

Creates a new instance of this R6 class.

Usage
AcqOptimizerLocalSearch$new(acq_function = NULL)
Arguments
acq_function

(NULL | AcqFunction).


Method optimize()

Optimize the acquisition function.

Usage
AcqOptimizerLocalSearch$optimize()
Returns

data.table::data.table() with 1 row per candidate.


Method reset()

Reset the acquisition function optimizer.

Currently not used.

Usage
AcqOptimizerLocalSearch$reset()

Method clone()

The objects of this class are cloneable with this method.

Usage
AcqOptimizerLocalSearch$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

Examples

acqo("local_search")

mlr3mbo documentation built on April 24, 2026, 5:07 p.m.