Local search acquisition function optimizer.
Calls bbotk::local_search().
For the meaning of the control parameters, see bbotk::local_search_control().
The termination stops when the budget defined by the n_searches, n_steps, and n_neighs parameters is exhausted.
mlr3mbo::AcqOptimizer -> AcqOptimizerLocalSearch
state(list())
List of cmaes::cma_es() results.
print_id(character)
Id used when printing.
Inherited methods
new()Creates a new instance of this R6 class.
AcqOptimizerLocalSearch$new(acq_function = NULL)acq_function(NULL | AcqFunction).
data.table::data.table() with 1 row per candidate.
reset()Reset the acquisition function optimizer.
Currently not used.
AcqOptimizerLocalSearch$reset()
clone()The objects of this class are cloneable with this method.
AcqOptimizerLocalSearch$clone(deep = FALSE)deepWhether to make a deep clone.