AcqOptimizerRandomSearch: Random Search Acquisition Function Optimizer

AcqOptimizerRandomSearchR Documentation

Random Search Acquisition Function Optimizer

Description

Random search acquisition function optimizer. By default, it samples 100 * D^2 random points in the search space, where D is the dimension of the search space. The point with the highest acquisition value is returned.

Parameters

n_evals

integer(1)
Number of random points to sample. Default is 100 * D^2, where D is the dimension of the search space.

Super class

mlr3mbo::AcqOptimizer -> AcqOptimizerRandomSearch

Active bindings

print_id

(character)
Id used when printing.

Methods

Public methods

Inherited methods

Method new()

Creates a new instance of this R6 class.

Usage
AcqOptimizerRandomSearch$new(acq_function = NULL)
Arguments
acq_function

(NULL | AcqFunction).


Method optimize()

Optimize the acquisition function.

Usage
AcqOptimizerRandomSearch$optimize()
Returns

data.table::data.table() with 1 row per candidate.


Method clone()

The objects of this class are cloneable with this method.

Usage
AcqOptimizerRandomSearch$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

Examples

acqo("random_search")

mlr3mbo documentation built on April 24, 2026, 5:07 p.m.