Random search acquisition function optimizer.
By default, it samples 100 * D^2 random points in the search space, where D is the dimension of the search space.
The point with the highest acquisition value is returned.
n_evalsinteger(1)
Number of random points to sample.
Default is 100 * D^2, where D is the dimension of the search space.
mlr3mbo::AcqOptimizer -> AcqOptimizerRandomSearch
print_id(character)
Id used when printing.
new()Creates a new instance of this R6 class.
AcqOptimizerRandomSearch$new(acq_function = NULL)acq_function(NULL | AcqFunction).
data.table::data.table() with 1 row per candidate.
clone()The objects of this class are cloneable with this method.
AcqOptimizerRandomSearch$clone(deep = FALSE)deepWhether to make a deep clone.