Learn R Programming

mlr3mbo (version 1.0.0)

mlr_acqoptimizers: Dictionary of Acquisition Function Optimizers

Description

A simple mlr3misc::Dictionary storing objects of class AcqOptimizer. Each input transformation has an associated help page, see mlr_acqoptimizers[id].

For a more convenient way to retrieve and construct an acquisition function optimizer, see acqo().

Arguments

Format

R6::R6Class object inheriting from mlr3misc::Dictionary.

Methods

See mlr3misc::Dictionary.

See Also

Sugar function: acqo()

Other Dictionary: mlr_acqfunctions, mlr_input_trafos, mlr_loop_functions, mlr_output_trafos, mlr_result_assigners

Examples

Run this code
library(data.table)
as.data.table(mlr_acqoptimizers)
acqo("local_search")

Run the code above in your browser using DataLab